@@ -9,11 +9,24 @@ function(mylevels, stroke, fill, shp, trans.pts, col.bg, usr) {
   by.name <- getOption("byname")
 
   legend.labels <- abbreviate(mylevels,6)
-  legend.title  <- abbreviate(by.name, 12)
-  ll <- legend(0,0, legend=legend.labels, title=legend.title, cex=.7,
-           fill="gray", plot=FALSE)
+  if (options("device") == "RStudioGD" && .Platform$OS != "windows") {
+    max.width <- which(nchar(legend.labels) == max(nchar(legend.labels)))
+    legend.labels[max.width] <- paste(legend.labels[max.width], "      ", sep="")
+  }
+
+  wt <- ifelse (options("device") == "RStudioGD", 10, 12)
+  legend.title  <- abbreviate(by.name, wt)
+  if (options("device") == "RStudioGD" && .Platform$OS != "windows") {
+    if (nchar(legend.title) > nchar(legend.labels[max.width][1]))
+      legend.title <- paste("  ", legend.title, "  ", sep="") 
+  }
+  ll <- legend(0,0, legend=legend.labels, title=legend.title, cex=.7, pt.cex=.9,
+            plot=FALSE)
+
   size <- (par("cxy")/par("cin"))  # 1 inch in user coordinates 
-  epsilon <- (size[1] - ll$rect$w) / 2
+
+  dv <- ifelse (options("device") == "RStudioGD", 1, 2)
+  epsilon <- (size[1] - ll$rect$w) / dv 
 
   axis.vert <- usr[4] - usr[3]
   xleft <- usr[2] + epsilon   # usr[2] user coordinate of right axis
@@ -31,8 +44,10 @@ function(mylevels, stroke, fill, shp, trans.pts, col.bg, usr) {
   colors <- getOption("colors")
   the.clr <- ifelse(grepl(".black", colors), "gray90", "black")
 
+  yi <- ifelse (options("device") == "RStudioGD", 1.4, 1)
   legend(xleft, ytop, legend=legend.labels, title=legend.title, 
          pch=shp, horiz=FALSE, cex=.7, pt.cex=.9, box.lwd=.5, 
-         box.col="gray30", bg=col.bg, col=stroke, pt.bg=fill, text.col=the.clr)
+         box.col="gray30", bg=col.bg, col=stroke, pt.bg=fill,
+         text.col=the.clr, y.intersp=yi)
 
 }
