@@ -342,10 +342,10 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
       plt.title[plt.i] <- paste("Ordered Data:", paste(Xnm, X1nm))
 
      .lc.main(YA, type=NULL,
-       col.line=getOption("col.stroke.pt"), col.area=NULL, col.box="black",
-       col.stroke=getOption("col.stroke.pt"), 
-       col.fill=getOption("col.fill.bar"), shape.pts=21,
-       col.grid=getOption("col.grid"), col.bg=getOption("col.bg"),
+       col.line=getOption("color.stroke.pt"), col.area=NULL, col.box="black",
+       col.stroke=getOption("color.stroke.pt"), 
+       col.fill=getOption("color.fill.bar"), shape.pts=21,
+       col.grid=getOption("color.grid"), col.bg=getOption("color.bg"),
        cex.axis=0.75, col.axis="gray30", rotate.values=0, offset=.5,
        xy.ticks=TRUE, line.width=1.1,
        xlab=NULL, ylab=paste(Ynm,": ",X1nm, sep=""),
@@ -367,10 +367,10 @@ function(YA, YB, n1, n2, m1, m2, s1, s2, from.data,
       plt.title[plt.i] <- paste("Ordered Data:", paste(Xnm, X2nm))
  
      .lc.main(YB, type=NULL,
-       col.line=getOption("col.stroke.pt"), col.area=NULL, col.box="black",
-       col.stroke=getOption("col.stroke.pt"), 
-       col.fill=getOption("col.fill.bar"), shape.pts=21,
-       col.grid=getOption("col.grid"), col.bg=getOption("col.bg"),
+       col.line=getOption("color.stroke.pt"), col.area=NULL, col.box="black",
+       col.stroke=getOption("color.stroke.pt"), 
+       col.fill=getOption("color.fill.bar"), shape.pts=21,
+       col.grid=getOption("color.grid"), col.bg=getOption("col.bg"),
        cex.axis=0.85, col.axis="gray30", rotate.values=0, offset=.5,
        xy.ticks=TRUE, line.width=1.1,
        xlab=NULL, ylab=paste(Ynm,": ",X2nm, sep=""),
